@@ -15,7 +15,7 @@ sys.path.append(os.path.normpath(os.path.join(SCRIPT_DIR, PACKAGE_PARENT)))
 from mypvdevices.ServerConnection import ServerConnection
 from mypvdevices.Dataprocessor import Dataprocessor
 
-BUILDNR = "1.2112.23"
+BUILDNR = "1.2202.2"
 
 JOINTIMEOUTSECONDS = 5
 MONITORSLEEPTIMESECONDS = 10
@@ -284,7 +284,7 @@ class GeneralDevice:
                             logging.warning(str(self._name) + ". Cannot get channelvalue")
                             channelvalue = None
                         setupvalue = self._setup[name].value
-                        if channelvalue != setupvalue:
+                        if channelvalue != None and channelvalue != setupvalue:
                             logging.info(str(self._name) + " setting missmatch " + str(name) + " - Device: " + str(channelvalue) + "; Setup: " + str(setupvalue) + ".")
                             if self._setup[name].forced:
                                 try:
